@@ -1,17 +1,26 @@
 package Task::POE::IRC;
+$Task::POE::IRC::VERSION = '1.14';
+#ABSTRACT: Task to install all POE related IRC modules.
 
 use strict;
 use warnings;
-our $VERSION = '1.12';
 
-1;
+qq[Tasky McTaskIRC];
 
 __END__
 
+=pod
+
+=encoding UTF-8
+
 =head1 NAME
 
 Task::POE::IRC - Task to install all POE related IRC modules.
 
+=head1 VERSION
+
+version 1.14
+
 =head1 SYNOPSIS
 
     perl -MCPANPLUS -e 'install Task::POE::IRC'
@@ -28,13 +37,15 @@ Task::POE::IRC - L<Task> to install all L<POE> related IRC modules and optional
 
   POE::Component::Server::IRC 1.32
 
-=head1 LICENSE
-
-This is free software, released under the same terms as perl itself.
-
 =head1 AUTHOR
 
-Chris C<BinGOs> Williams <chris@bingosnet.co.uk>
+Chris Williams <chris@bingosnet.co.uk>
+
+=head1 COPYRIGHT AND LICENSE
+
+This software is copyright (c) 2017 by Chris Williams.
+
+This is free software; you can redistribute it and/or modify it under
+the same terms as the Perl 5 programming language system itself.
 
 =cut
-
